@@ -9,7 +9,7 @@ import logging
 from typing import NamedTuple
 
 from ..storage import loaders, savers
-from ..streams import FileFormatError
+from ..magic import FileFormatError
 from ..font import Font
 from ..glyph import Glyph
 from ..properties import Props, reverse_dict, extend_string
@@ -20,13 +20,15 @@ from ..taggers import tagmaps
 # as we only work with monochrome bitmaps
 
 
-
 ##############################################################################
 # interface
 
-
-@loaders.register('flf', magic=(b'flf2a',), name='figlet')
-def load_figlet(instream, where=None, *, ink:str=''):
+@loaders.register(
+    name='figlet',
+    magic=(b'flf2a',),
+    patterns=('*.flf',),
+)
+def load_figlet(instream, *, ink:str=''):
     """Load font from a FIGlet .flf file."""
     flf_glyphs, flf_props, comments = _read_flf(instream.text, ink=ink)
     logging.info('figlet properties:')
@@ -39,7 +41,7 @@ def load_figlet(instream, where=None, *, ink:str=''):
     return Font(glyphs, comment=comments, **vars(props))
 
 @savers.register(linked=load_figlet)
-def save_figlet(fonts, outstream, where=None):
+def save_figlet(fonts, outstream):
     """Write fonts to a FIGlet .flf file."""
     if len(fonts) > 1:
         raise FileFormatError('Can only save one font to .flf file.')
